@@ -453,6 +453,9 @@ class DrawProcessThreejs(Process):
     def run_flask(self, port):
         from flask import Flask, url_for, jsonify, request, send_from_directory, redirect
         from waitress import serve
+        from mimetypes import add_type
+        add_type('application/javascript', '.js')
+        add_type('text/css', '.css')
 
         app = Flask(__name__)
         dirname = os.path.dirname(__file__) + '/threejsmod'
@@ -491,7 +494,8 @@ class DrawProcessThreejs(Process):
         print('JS visualizer online: http://%s:%d'%(get_host_ip(), port))
         print('JS visualizer online (localhost): http://localhost:%d'%(port))
         print('--------------------------------')
-        serve(app, threads=8, ipv4=True, ipv6=True, listen='*:%d'%port)
+        # app.run(host='0.0.0.0', port=port)
+        serve(app, threads=4, ipv4=True, ipv6=True, listen='*:%d'%port)
 
 
 class DrawProcess(Process):
